#include <iostream>
#include "string.h"
#include "unistd.h"
#include <iowkit.h>


#define LW14_I2CADR 0x40 //8Bit adr

#define LW14_REG_STATUS 0x00
#define LW14_REG_COMMAND 0x01
//...


#define LW14_DALIMODE_DACP 0x00
#define LW14_DALIMODE_CMD  0x01





using namespace std;

int main (int argc, char *argv[])
{

    IOWKIT_HANDLE handle;
    IOWKIT_SPECIAL_REPORT report;


    handle = IowKitOpenDevice();    //Open IO-Warrior (get the first connected device)

    if(handle != NULL)
    {
        IowKitSetTimeout(handle, 1000); //Set timeout to kill write/read actions after X ms if something goes wrong

        //Enable I2C-Mode
        //For more information take a look into the datashee of IO-Warrior24
        memset(&report, 0, IOWKIT_SPECIAL_REPORT_SIZE);
        report.ReportID = 0x01;     //Use I2C mode of IO-Warrior
        report.Bytes[0] = 0x01;     //Enable I2C mode, 0x00 will disable it
        report.Bytes[1] = 0x00;     //Flags
        report.Bytes[2] = 0x00;     //Timeout

        //Send data to device, no response!
        IowKitWrite(handle, IOW_PIPE_SPECIAL_MODE, (char*) &report, IOWKIT_SPECIAL_REPORT_SIZE);


        BYTE dali_int = 62; //DALI device between 0 and 63
        BYTE dali_adr = (62 << 1) | LW14_DALIMODE_DACP; //To generate a DALI address
        BYTE dali_value = 200;  //DALI command like MAX, MIN odr DACP-Value between 0 and 254

        //Send data to device

        report.ReportID = 0x02;			    //I2C-Mode: Write
        report.Bytes[0] = 0xC4;			    //Start + Stop bit + data count (I2C-Address + register + data)
        report.Bytes[1] = LW14_I2CADR;	    //I2C write address
        report.Bytes[2] = LW14_REG_COMMAND;	//register
        report.Bytes[3] = dali_adr;	        //data -> DALI address : Format = Y AAA AAA 1
        report.Bytes[4] = dali_value;       //data -> DALI command or DACP value

        if (IowKitWrite(handle, IOW_PIPE_SPECIAL_MODE, (char*)&report, IOWKIT_SPECIAL_REPORT_SIZE) == IOWKIT_SPECIAL_REPORT_SIZE)  //Write to IO-Warrior
        {
            if (IowKitRead(handle, IOW_PIPE_SPECIAL_MODE, (char*)&report, IOWKIT_SPECIAL_REPORT_SIZE) == IOWKIT_SPECIAL_REPORT_SIZE)	//Read ACK from IO-Warrior
            {
                if ((report.Bytes[0] & 0x80) == 0x80)  //Error, no ACK from I2C-device
                    printf("Errorbit found ! \n");
                else if (report.Bytes[0] == 4)  //Byte[0] must be equal data count -> Success
                    printf("Write successful\n");
                else
                    printf("Error\n");
            }
            else
                printf("Error during read ACK\n");
        }
        else
            printf("Error during write\n");

    }
    IowKitCloseDevice(handle);  //Close the iowkit API. DONT FORGET IT !!!!!

    return 0;
}
